OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Sikertelen kérés, a hálózati kapcsolat nem elérhető!",
    "Request unauthorized. Are you logged in?" : "Jogosulatlan kérés. Be vagy jelentkezve?",
    "Request forbidden. Are you an admin?" : "Tiltott kérés. Rendszergazda vagy?",
    "Token expired or app not enabled! Reload the page!" : "Lejárt a token vagy az alkalmazás nem engedélyezett. Töltsd újra az oldalt!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Belő szerverhiba! További információkért kérlek ellenőrizd a data/nextcloud.log fájlt!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Kérés sikértelen. A Nextcloud jelenleg karbantartási módban van.",
    "Can not add feed: Exists already" : "Nem sikerült hozzáadni a hírfolyamot: már létezik",
    "Articles without feed" : "Cikkek hírfolyam nélkül",
    "Can not add folder: Exists already" : "A mappa nem hozható létre: már létezik",
    "News" : "Hírek",
    "An RSS/Atom feed reader" : "Egy RSS/Atom-hírcsatorna olvasó",
    "Use system cron for updates" : "A frissítésekhez használd a rendszer cront",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Kapcsold ki ha saját frissítőt használsz, mint például az apphoz csatolt Python frissítő",
    "Purge interval" : "Tisztogatási időköz",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Minimum idő másodpercben, melyen belül a törölt folyamok és mappák véglegesen kikerülnek az adatbázisból. A 60 másodperc alatti értékeket figyelmen kívül hagyjuk",
    "Maximum read count per feed" : "Maximális olvasási szám hífolyamonként",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Meghatározza az egy folyamon olvasható hírek számát, melyeket a takarító folyamat meghagy. Ha korábban olvasott hírek ismét bekerülnek, növeld ezt a számot. Negatív értékek, pl a -1, kikapcsolja ezt a szolgáltatást",
    "Maximum redirects" : "Maximum átirányítás",
    "How many redirects the feed fetcher should follow" : "Hány átirányítást kövessen a hírfolyam letöltő",
    "Maximum feed page size" : "Maximum hírfolyam oldalméret",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Maximális hírcsatorna méret byte-ban. Ha az RSS/Atom oldal nagyobb mint ez az érték, a frissítés meg lesz szakítva",
    "Feed fetcher timeout" : "Hírfolyam letöltő időtúllépés",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "A maximális időtartam amit egy RSS vagy Atom hírcsatorna olvasására vár. Ha tovább tart a frissítés meg lesz szakítva",
    "Explore Service URL" : "Szolgáltatásfelderítési URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Ha meg van adva, ezt a szolgáltatási címet ellenőrzi a folyam megjelenítő szekció megnyitásakor. Az eredeti szolgáltatásböngésző használatához hagyd üresen",
    "For more information check the wiki" : "További információkért nézd meg a wikit",
    "Saved" : "Elmentve",
    "Download" : "Letöltés",
    "Close" : "Bezárás",
    "filter" : "szűrő",
    "Language" : "Nyelv",
    "Subscribe" : "Feliratkozás",
    "Got more awesome feeds? Share them with us!" : "Van néhány nagyszerű hírfolyamod? Oszd meg velünk!",
    "No articles available" : "Nincsenek elérhető cikkek",
    "No unread articles available" : "Nincsenek elérhető olvasatlan cikkek",
    "Open website" : "Weboldal megnyitása",
    "Star article" : "Cikk csillagozása",
    "Unstar article" : "Cikk csillagozás eltávolítása",
    "Keep article unread" : "Cikk maradjon olvasatlan",
    "Remove keep article unread" : "Az olvasatlanban tartás eltávolítása",
    "by" : "közreadta:",
    "from" : "forrás:",
    "Play audio" : "Hang lejátszás",
    "Download video" : "Videó letöltés",
    "Download audio" : "Hang letöltés",
    "Keyboard shortcut" : "Billyentyűparancs",
    "Description" : "Leírás",
    "right" : "jobb",
    "Jump to next article" : "Ugrás a következő cikkre",
    "left" : "bal",
    "Jump to previous article" : "Ugrás az előző cikkre",
    "Toggle star article" : "Cikk csillagozás váltása",
    "Star article and jump to next one" : "Cikk csillagozása és ugrás a következőre",
    "Toggle keep current article unread" : "Cikk maradjon olvasatlan váltása",
    "Open article in new tab" : "Cikk megnyitása új lapon",
    "Toggle expand article in compact view" : "Cikk kibontásának váltása kompakt nézetben",
    "Refresh" : "Frissítés",
    "Load next feed" : "Következő hírfolyam betöltése",
    "Load previous feed" : "Előző hírfolyam betöltése",
    "Load next folder" : "Következő mappa betöltése",
    "Load previous folder" : "Előző mappa betöltése",
    "Scroll to active navigation entry" : "Görgetés az aktív navigációs bejegyzéshez",
    "Focus search field" : "Fókusz a kereső mezőn",
    "Mark current article's feed/folder read" : "Aktuális cikk hírfolyamának/mappájának megjelölése olvasottként",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax vagy webcron mód érzékelve! A folyamaid nem lesznek frissítve!",
    "How to set up the operating system cron" : "Hogyan állítsd be az operációs rendszer időzítőjét",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Új gyorsabb, párhuzamosított frissítő telepítése, mely a hírek app API-ját használja",
    "Web address" : "Web cím",
    "Feed exists already!" : "A hírfolyam már létezik!",
    "Folder" : "Mappa",
    "No folder" : "Nincs mappa",
    "New folder" : "Új mappa",
    "Folder name" : "Mappanév",
    "Go back" : "Menj vissza",
    "Folder exists already!" : "A mappa már létezik!",
    "Credentials" : "Azonosítók",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "A HTTP alapértelmezett azonosítási adatok titkosítatlanul tárolódnak! Bárki aki hozzáfér a szerverhez vagy az adatbázishoz olvashatja azt!",
    "Username" : "Felhasználónév",
    "Password" : "Jelszó",
    "New Folder" : "Új mappa",
    "Create" : "Létrehozás",
    "Explore" : "Felfedezés",
    "Update failed more than 50 times" : "Sikertelen frissítés több mint 50-szer",
    "Deleted feed" : "Törölt hírfolyam",
    "Undo delete feed" : "Hírfolyam törlés visszavonása",
    "Rename" : "Átnevezés",
    "Menu" : "Menü",
    "Mark read" : "Olvasottnak jelöl",
    "Unpin from top" : "Rögzítés feloldása",
    "Pin to top" : "Rögzítés a tetején",
    "Newest first" : "Legújabb először",
    "Oldest first" : "Legrégebbi először",
    "Default order" : "Alapértelmezett sorrend",
    "Enable full text" : "Teljes szöveges mód engedélyezése",
    "Disable full text" : "Teljes szöveges mód letiltása",
    "Unread updated" : "Olvasatlan frissítés",
    "Ignore updated" : "Frissítés figyelmen kívül hagyása!",
    "Open feed URL" : "Hírfolyam URL megnyitása",
    "Delete" : "Törlés",
    "Dismiss" : "Elutasít",
    "Collapse" : "Összecsukás",
    "Deleted folder" : "Törölt mappa",
    "Undo delete folder" : "Mappa törlés visszavonása",
    "Starred" : "Csillagozott",
    "Unread articles" : "Olvasatlan cikkek",
    "All articles" : "Az összes cikk",
    "Settings" : "Beállítások",
    "Disable mark read through scrolling" : "Görgetés közbeni olvasottnak jelölés kikapcsolása",
    "Compact view" : "Kompakt nézet",
    "Expand articles on key navigation" : "Cikkek kibontása billentyű navikációkor",
    "Show all articles" : "Minden cikk megjelenítése",
    "Reverse ordering (oldest on top)" : "Fordított sorrend (régebbi felül)",
    "Subscriptions (OPML)" : "Feliratkozások (OPML)",
    "Import" : "Importálás",
    "Export" : "Exportálás",
    "Error when importing: File does not contain valid OPML" : "Hiba importáláskor: A fájl nem tartalmaz érvényes OPML-t",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Hiba történt az importálás közben: az OPML nem tartalmaz sem hírfolyamokat, sem mappákat",
    "Unread/Starred Articles" : "Olvastlan/Csillagozott cikkek",
    "Error when importing: file does not contain valid JSON" : "Hiba az importálás során: a fájl nem tartalmaz érvényes JSON adatokat",
    "Help" : "Súgó",
    "Keyboard shortcuts" : "Gyorsbillentyűk",
    "Documentation" : "Dokumentáció",
    "Report a bug" : "Hiba bejelentése"
},
"nplurals=2; plural=(n != 1);");
